==> estateplat-common-1.2.4-20220622.065714-1051-sources.jar: cn/gtmap/estateplat/model/exchange/national/newStandard/DjtDjSlNew.java <==
package cn.gtmap.estateplat.model.exchange.national.newStandard;

import cn.gtmap.estateplat.model.exchange.national.AccessData;
import cn.gtmap.estateplat.utils.JaxbDateAdapter;
import cn.gtmap.estateplat.utils.JaxbNotNullDateAdapter;
import cn.gtmap.estateplat.utils.JaxbNotNullIntegerAdapter;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;

import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import java.io.Serializable;
import java.util.Date;

@XmlRootElement(name = "DJT_DJ_SL")
@Table(name = "DJT_DJ_SL")
public class DjtDjSlNew implements Serializable, AccessData {
    final static String ysdm = "6004020000";//要素代码
    private String ywh;//业务号
    private String qxdm;//区县代码
    private Integer sqzsbs;//申请证书板式
    private Integer sqfbcz;//申请分别持证
    private String slry;//受理人员
    private Date slsj;//受理时间
    private String zl;//坐落
    private String tzrxm;//通知人姓名
    private String tzfs;//通知方式
    private String tzrdh;//通知人电话
    private String tzryddh;//通知人移动电话
    private String tzrdzyj;//通知人电子邮件
    private String sfwtaj;//是否问题案件
    private Date jssj;//结束时间
    private String ajzt;//案件状态
    private String bz;//备注

    /**  插入更新时间
     * @author <a href="mailto:zhangqiang@gtmap.cn">zhangqiang</a>
     * @description
     */
    private Date updatetime;
    /**  插入创建时间
     * @author <a href="mailto:zhangqiang@gtmap.cn">zhangqiang</a>
     * @description
     */
    private Date createtime;

    private String djlx;
    @XmlAttribute(name = "DJLX")
    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    @XmlTransient
    public Date getCreatetime() {
        return createtime;
    }

    public void setCreatetime(Date createtime) {
        this.createtime = createtime;
    }
    @XmlTransient
    public Date getUpdatetime() {
        return updatetime;
    }

    public void setUpdatetime(Date updatetime) {
        this.updatetime = updatetime;
    }

    @XmlAttribute(name = "YSDM")
    public String getYsdm() {
        return ysdm;
    }

    @XmlAttribute(name = "YWH")
    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    @XmlAttribute(name = "QXDM")
    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    @XmlAttribute(name = "SQZSBS")
    @XmlJavaTypeAdapter(JaxbNotNullIntegerAdapter.class)
    public Integer getSqzsbs() {
        return sqzsbs;
    }

    public void setSqzsbs(Integer sqzsbs) {
        this.sqzsbs = sqzsbs;
    }

    @XmlAttribute(name = "SQFBCZ")
    @XmlJavaTypeAdapter(JaxbNotNullIntegerAdapter.class)
    public Integer getSqfbcz() {
        return sqfbcz;
    }

    public void setSqfbcz(Integer sqfbcz) {
        this.sqfbcz = sqfbcz;
    }

    @XmlAttribute(name = "SLRY")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getSlry() {
        return slry;
    }

    public void setSlry(String slry) {
        this.slry = slry;
    }

    @XmlAttribute(name = "SLSJ")
    @XmlJavaTypeAdapter(JaxbNotNullDateAdapter.class)
    public Date getSlsj() {
        return slsj;
    }

    public void setSlsj(Date slsj) {
        this.slsj = slsj;
    }

    @XmlAttribute(name = "ZL")
    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    @XmlAttribute(name = "TZRXM")
    public String getTzrxm() {
        return tzrxm;
    }

    public void setTzrxm(String tzrxm) {
        this.tzrxm = tzrxm;
    }

    @XmlAttribute(name = "TZFS")
    public String getTzfs() {
        return tzfs;
    }

    public void setTzfs(String tzfs) {
        this.tzfs = tzfs;
    }

    @XmlAttribute(name = "TZRDH")
    public String getTzrdh() {
        return tzrdh;
    }

    public void setTzrdh(String tzrdh) {
        this.tzrdh = tzrdh;
    }

    @XmlAttribute(name = "TZRYDDH")
    public String getTzryddh() {
        return tzryddh;
    }

    public void setTzryddh(String tzryddh) {
        this.tzryddh = tzryddh;
    }

    @XmlAttribute(name = "TZRDZYJ")
    public String getTzrdzyj() {
        return tzrdzyj;
    }

    public void setTzrdzyj(String tzrdzyj) {
        this.tzrdzyj = tzrdzyj;
    }

    @XmlAttribute(name = "SFWTAJ")
    public String getSfwtaj() {
        return sfwtaj;
    }

    public void setSfwtaj(String sfwtaj) {
        this.sfwtaj = sfwtaj;
    }

    @XmlAttribute(name = "JSSJ")
    @XmlJavaTypeAdapter(JaxbNotNullDateAdapter.class)
    public Date getJssj() {
        return jssj;
    }

    public void setJssj(Date jssj) {
        this.jssj = jssj;
    }

    @XmlAttribute(name = "AJZT")
    public String getAjzt() {
        return ajzt;
    }

    public void setAjzt(String ajzt) {
        this.ajzt = ajzt;
    }

    @XmlAttribute(name = "BZ")
    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }
}

==> estateplat-common-1.2.4-20240814.012233-1246-sources.jar: cn/gtmap/estateplat/model/exchange/national/newStandard/DjtDjSlNew.java <==
package cn.gtmap.estateplat.model.exchange.national.newStandard;

import cn.gtmap.estateplat.model.exchange.national.AccessData;
import cn.gtmap.estateplat.utils.JaxbDateAdapter;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;

import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import java.io.Serializable;
import java.util.Date;

@XmlRootElement(name = "DJT_DJ_SL")
@Table(name = "DJT_DJ_SL")
public class DjtDjSlNew implements Serializable, AccessData {
    final static String ysdm = "6004020000";//要素代码
    private String ywh;//业务号
    private String qxdm;//区县代码
    private Integer sqzsbs;//申请证书板式
    private Integer sqfbcz;//申请分别持证
    private String slry;//受理人员
    private Date slsj;//受理时间
    private String zl;//坐落
    private String tzrxm;//通知人姓名
    private String tzfs;//通知方式
    private String tzrdh;//通知人电话
    private String tzryddh;//通知人移动电话
    private String tzrdzyj;//通知人电子邮件
    private String sfwtaj;//是否问题案件
    private Date jssj;//结束时间
    private String ajzt;//案件状态
    private String bz;//备注

    /**  插入更新时间
     * @author <a href="mailto:zhangqiang@gtmap.cn">zhangqiang</a>
     * @description
     */
    private Date updatetime;
    /**  插入创建时间
     * @author <a href="mailto:zhangqiang@gtmap.cn">zhangqiang</a>
     * @description
     */
    private Date createtime;

    private String djlx;
    private String cjrmc;//创建人名称
    private String cjrjs;//创建人角色
    private String cjly;//创建来源

    @XmlAttribute(name = "DJLX")
    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    @XmlTransient
    public Date getCreatetime() {
        return createtime;
    }

    public void setCreatetime(Date createtime) {
        this.createtime = createtime;
    }
    @XmlTransient
    public Date getUpdatetime() {
        return updatetime;
    }

    public void setUpdatetime(Date updatetime) {
        this.updatetime = updatetime;
    }

    @XmlAttribute(name = "YSDM")
    public String getYsdm() {
        return ysdm;
    }

    @XmlAttribute(name = "YWH")
    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    @XmlAttribute(name = "QXDM")
    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    @XmlAttribute(name = "SQZSBS")
    public Integer getSqzsbs() {
        return sqzsbs;
    }

    public void setSqzsbs(Integer sqzsbs) {
        this.sqzsbs = sqzsbs;
    }

    @XmlAttribute(name = "SQFBCZ")
    public Integer getSqfbcz() {
        return sqfbcz;
    }

    public void setSqfbcz(Integer sqfbcz) {
        this.sqfbcz = sqfbcz;
    }

    @XmlAttribute(name = "SLRY")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getSlry() {
        return slry;
    }

    public void setSlry(String slry) {
        this.slry = slry;
    }

    @XmlAttribute(name = "SLSJ")
    @XmlJavaTypeAdapter(JaxbDateAdapter.class)
    public Date getSlsj() {
        return slsj;
    }

    public void setSlsj(Date slsj) {
        this.slsj = slsj;
    }

    @XmlAttribute(name = "ZL")
    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    @XmlAttribute(name = "TZRXM")
    public String getTzrxm() {
        return tzrxm;
    }

    public void setTzrxm(String tzrxm) {
        this.tzrxm = tzrxm;
    }

    @XmlAttribute(name = "TZFS")
    public String getTzfs() {
        return tzfs;
    }

    public void setTzfs(String tzfs) {
        this.tzfs = tzfs;
    }

    @XmlAttribute(name = "TZRDH")
    public String getTzrdh() {
        return tzrdh;
    }

    public void setTzrdh(String tzrdh) {
        this.tzrdh = tzrdh;
    }

    @XmlAttribute(name = "TZRYDDH")
    public String getTzryddh() {
        return tzryddh;
    }

    public void setTzryddh(String tzryddh) {
        this.tzryddh = tzryddh;
    }

    @XmlAttribute(name = "TZRDZYJ")
    public String getTzrdzyj() {
        return tzrdzyj;
    }

    public void setTzrdzyj(String tzrdzyj) {
        this.tzrdzyj = tzrdzyj;
    }

    @XmlAttribute(name = "SFWTAJ")
    public String getSfwtaj() {
        return sfwtaj;
    }

    public void setSfwtaj(String sfwtaj) {
        this.sfwtaj = sfwtaj;
    }

    @XmlAttribute(name = "JSSJ")
    @XmlJavaTypeAdapter(JaxbDateAdapter.class)
    public Date getJssj() {
        return jssj;
    }

    public void setJssj(Date jssj) {
        this.jssj = jssj;
    }

    @XmlAttribute(name = "AJZT")
    public String getAjzt() {
        return ajzt;
    }

    public void setAjzt(String ajzt) {
        this.ajzt = ajzt;
    }

    @XmlAttribute(name = "BZ")
    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    @XmlAttribute(name = "CJRMC")
    public String getCjrmc() {
        return cjrmc;
    }

    public void setCjrmc(String cjrmc) {
        this.cjrmc = cjrmc;
    }

    @XmlAttribute(name = "CJRJS")
    public String getCjrjs() {
        return cjrjs;
    }

    public void setCjrjs(String cjrjs) {
        this.cjrjs = cjrjs;
    }

    @XmlAttribute(name = "CJLY")
    public String getCjly() {
        return cjly;
    }

    public void setCjly(String cjly) {
        this.cjly = cjly;
    }
}
